==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/AbortFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface AbortFluent<A extends AbortFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildErrorType instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.Abort.ErrorType getErrorType();
    public me.snowdrop.istio.api.networking.v1alpha3.Abort.ErrorType buildErrorType();
    public A withErrorType(me.snowdrop.istio.api.networking.v1alpha3.Abort.ErrorType errorType);
    public Boolean hasErrorType();
    public A withHttpStatusErrorType(HttpStatusErrorType httpStatusErrorType);
    public AbortFluent.HttpStatusErrorTypeNested<A> withNewHttpStatusErrorType();
    public AbortFluent.HttpStatusErrorTypeNested<A> withNewHttpStatusErrorTypeLike(HttpStatusErrorType item);
    public A withNewHttpStatusErrorType(Integer httpStatus);
    public A withGrpcStatusErrorType(GrpcStatusErrorType grpcStatusErrorType);
    public AbortFluent.GrpcStatusErrorTypeNested<A> withNewGrpcStatusErrorType();
    public AbortFluent.GrpcStatusErrorTypeNested<A> withNewGrpcStatusErrorTypeLike(GrpcStatusErrorType item);
    public A withNewGrpcStatusErrorType(String grpcStatus);
    public A withHttp2ErrorType(Http2ErrorErrorType http2ErrorType);
    public AbortFluent.Http2ErrorTypeNested<A> withNewHttp2ErrorType();
    public AbortFluent.Http2ErrorTypeNested<A> withNewHttp2ErrorTypeLike(Http2ErrorErrorType item);
    public A withNewHttp2ErrorType(String http2Error);
    public Integer getPercent();
    public A withPercent(Integer percent);
    public Boolean hasPercent();
    public A withNewPercent(String arg1);
    public A withNewPercent(int arg1);

    public interface HttpStatusErrorTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpStatusErrorTypeFluent<AbortFluent.HttpStatusErrorTypeNested<N>>{

        
    public N and();    public N endHttpStatusErrorType();
}
    public interface GrpcStatusErrorTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GrpcStatusErrorTypeFluent<AbortFluent.GrpcStatusErrorTypeNested<N>>{

        
    public N and();    public N endGrpcStatusErrorType();
}
    public interface Http2ErrorTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,Http2ErrorErrorTypeFluent<AbortFluent.Http2ErrorTypeNested<N>>{

        
    public N and();    public N endHttp2ErrorType();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/AbortFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Double;
import java.lang.Integer;

public interface AbortFluent<A extends AbortFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildErrorType instead.
 * @return The buildable object.
 */
@Deprecated public Abort.ErrorType getErrorType();
    public Abort.ErrorType buildErrorType();
    public A withErrorType(Abort.ErrorType errorType);
    public Boolean hasErrorType();
    public A withHttpStatusErrorType(HttpStatusErrorType httpStatusErrorType);
    public AbortFluent.HttpStatusErrorTypeNested<A> withNewHttpStatusErrorType();
    public AbortFluent.HttpStatusErrorTypeNested<A> withNewHttpStatusErrorTypeLike(HttpStatusErrorType item);
    public A withNewHttpStatusErrorType(Integer httpStatus);
    public A withGrpcStatusErrorType(GrpcStatusErrorType grpcStatusErrorType);
    public AbortFluent.GrpcStatusErrorTypeNested<A> withNewGrpcStatusErrorType();
    public AbortFluent.GrpcStatusErrorTypeNested<A> withNewGrpcStatusErrorTypeLike(GrpcStatusErrorType item);
    public A withNewGrpcStatusErrorType(String grpcStatus);
    public A withHttp2ErrorType(Http2ErrorErrorType http2ErrorType);
    public AbortFluent.Http2ErrorTypeNested<A> withNewHttp2ErrorType();
    public AbortFluent.Http2ErrorTypeNested<A> withNewHttp2ErrorTypeLike(Http2ErrorErrorType item);
    public A withNewHttp2ErrorType(String http2Error);
    public Integer getPercent();
    public A withPercent(Integer percent);
    public Boolean hasPercent();
    
/**
 * This method has been deprecated, please use method buildPercentage instead.
 * @return The buildable object.
 */
@Deprecated public Percent getPercentage();
    public Percent buildPercentage();
    public A withPercentage(Percent percentage);
    public Boolean hasPercentage();
    public A withNewPercentage(Double value);
    public AbortFluent.PercentageNested<A> withNewPercentage();
    public AbortFluent.PercentageNested<A> withNewPercentageLike(Percent item);
    public AbortFluent.PercentageNested<A> editPercentage();
    public AbortFluent.PercentageNested<A> editOrNewPercentage();
    public AbortFluent.PercentageNested<A> editOrNewPercentageLike(Percent item);

    public interface HttpStatusErrorTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpStatusErrorTypeFluent<AbortFluent.HttpStatusErrorTypeNested<N>>{

        
    public N and();    public N endHttpStatusErrorType();
}
    public interface GrpcStatusErrorTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GrpcStatusErrorTypeFluent<AbortFluent.GrpcStatusErrorTypeNested<N>>{

        
    public N and();    public N endGrpcStatusErrorType();
}
    public interface Http2ErrorTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,Http2ErrorErrorTypeFluent<AbortFluent.Http2ErrorTypeNested<N>>{

        
    public N and();    public N endHttp2ErrorType();
}
    public interface PercentageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PercentFluent<AbortFluent.PercentageNested<N>>{

        
    public N and();    public N endPercentage();
}


}
